from setuptools import setup

setup(name='ie_mbdbl2017_A_yahoo_ks_datareader',
      version='0.5',  # Development release
      description='Python package to retrieve the Price/Sales for technology stocks starting 06/03/2018 as part of Risk & Fraud course IE GMBD 2017',
	  long_description='Python package to retrieve the Price/Sales for technology stocks starting 06/03/2018 as part of Risk & Fraud course IE GMBD 2017',
      url='https://github.com/michela23/ie_mbdbl2017_A_yahoo_ks_datareader',
      author='IE GMBD 2017 Group A',
      author_email='michel.aa@student.ie.edu',
      license='MIT',
          packages=['ie_mbdbl2017_A_yahoo_ks_datareader'],
      zip_safe=False)